/******************************************************************************
*
*  Module Name: WPSTUTOR
*
*  Description: OS/2 Work Place Shell Sample Program
*
*               This class subclasses the WPDataFile class.  Most WPS
*               instance and class methods are overridden to invoke
*               'DisplayMethodInfo'.  This function uses a named pipe
*               to communicate with the 'Show Method Description'
*               (SHOWDESC.EXE) program, which displays the name and a
*               description of the method that invoked
*               'DisplayMethodInfo'.
*
*  Copyright (C) 1993 IBM Corporation
*
*      DISCLAIMER OF WARRANTIES.  The following [enclosed] code is
*      sample code created by IBM Corporation. This sample code is not
*      part of any standard or IBM product and is provided to you solely
*      for  the purpose of assisting you in the development of your
*      applications.  The code is provided "AS IS", without
*      warranty of any kind.  IBM shall not be liable for any damages
*      arising out of your use of the sample code, even if they have been
*      advised of the possibility of such damages.                                                    *
*
******************************************************************************/

###   Note: The header preceding this comment will be emitted in all files.
###
###         Any comments to go public should be preceded with '--'
###         Any comments to remain private should be preceded with '#'

#******************************************************************************
#   Include the class definition file for the parent class
#******************************************************************************
include <wpdataf.sc>

#******************************************************************************
#   Define the new class
#******************************************************************************
class: WPSTutorial,                      # Class name
       file stem       = wpstutor,       # Name for SOM-generated files
       function prefix = wpstut_,        # Method function name prefix
       classprefix     = wpstutM_,       # Class method name prefix
       major version   = 1,
       minor version   = 1,
       local;                            # Use "" for include files

--
-- CLASS: WPSTutorial
--
-- CLASS HIERARCHY:
--
--     SOMObject
--        WPObject
--              WPFileSystem
--                    WPDataFile
--                          WPSTutorial
--
-- DESCRIPTION:
--
--    This is the sample WPS tutorial object class.  This class subclasses
--    the WPDataFile class.  Most WPS instance and class methods are
--    overridden to invoke 'DisplayMethodInfo'.  This function uses a named
--    pipe to communicate with the 'Show Method Description' (SHOWDESC.EXE)
--    program, which displays the name and a description of the method that
--    invoked 'DisplayMethodInfo'.
--
--    An instance of this class can be created as a Workplace object.
--

#******************************************************************************
#   Specify the parent class
#******************************************************************************

parent: WPDataFile;

#******************************************************************************
#   Specify the release order of new methods.  This ensures binary
#   compatability if we change the order of our methods in .c and .csc files.
#******************************************************************************

release order: DisplayTitleInfo,
               clsQueryModuleHandle;

#******************************************************************************
#   Passthru PRIVATE definitions to the .ph file
#******************************************************************************
passthru: C.ph;

/*
**  The following structure is used to store window specific data
**  and a pointer to the object that created the window.
**
**  This structure is allocated when the Client window is created.
**  This allows us to pass the *somSelf pointer and use it in our window
**  and dialog procedures (the system only passes this pointer to
**  methods).
*/

typedef struct _WINDOWDATA
{
   USHORT       cb;            /* size of this structure */
   WPSTutorial  *somSelf;       /* pointer to this instance */
   USEITEM      UseItem;       /* global class usage information */
   VIEWITEM     ViewItem;      /* global class view information */
} WINDOWDATA;
typedef WINDOWDATA *PWINDOWDATA;

/*
**  Private debug helpers go here.  They can be enabled or disabled by
**  defining DEBUG as a compiler directive.
*/
#if defined(DEBUG)

   #define DebugBox(title, text) \
                                 \
              WinMessageBox(     \
                 HWND_DESKTOP,   \
                 HWND_DESKTOP,   \
                 (PSZ) text,     \
                 (PSZ) title,    \
                 20,             \
                 MB_OK | MB_INFORMATION | MB_MOVEABLE)
#else

   #define DebugBox(title, text)   /* do nothing if not debugging */

#endif

endpassthru;

#******************************************************************************
#   Passthru IMPLEMENTATION definitions to the .ih file
#******************************************************************************
passthru: C.ih;

#define INCL_WIN
#define INCL_DOS
#define INCL_WPCLASS

#include <os2.h>
#include <stdlib.h>
#include <string.h>

/*
**   The following user-defined Popup menu items (ID_xxx) should be higher
**   than WPMENUID_USER.
**
**   The ID_OPENMENU will become a submenu of the system's popup open menu
**   id, WPMENUID_OPEN.
*/
#define ID_OPENMENU     (WPMENUID_USER+1)   /* "Open" item in context menu   */
#define IDM_OPENTUT     (WPMENUID_USER+2)   /* "Open tutorial" item added    */
                                            /*   to "Open" menu              */
#define ID_ICON         101                 /* Icon for the WPSTutorial class*/

/*
**  Window IDs
*/
#define ID_FRAME        3000                /* Client window ID for the      */
                                            /*   "open" view                 */
/*
**  Unique view IDs
*/
#define OPEN_TUTORIAL   ID_OPENMENU         /* "Open tutorial" view ID       */

endpassthru;

#******************************************************************************
#   Passthru PUBLIC definitions to the .h file
#******************************************************************************
passthru: C.h;

endpassthru;

#******************************************************************************
#   Define instance data
#******************************************************************************
# data:

#******************************************************************************
#   Define new methods
#******************************************************************************
methods:

HWND DisplayTitleInfo();
--
-- METHOD: DisplayTitleInfo                               ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   This method handles the processing of the "Open tutorial" menu item
--   in the "Open" menu of the object's context menu.  The method creates a
--   PM window in order to display the (backwards) title of the object in
--   the window's title bar.
--
-- RETURN:
--
--   HWND - Handle to the window created
--

#******************************************************************************
#   Specify methods being overridden
#******************************************************************************


override wpAddFileMenuPage;
--
--  METHOD: wpAddFileMenuPage                              ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpAddFileTypePage;
--
--  METHOD: wpAddFileTypePage                              ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpAddFile1Page;
--
--  METHOD: wpAddFile1Page                                 ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpAddFile2Page;
--
--  METHOD: wpAddFile2Page                                 ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpAddFile3Page;
--
--  METHOD: wpAddFile3Page                                 ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpAddObjectGeneralPage;
--
--  METHOD: wpAddObjectGeneralPage                         ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpAddSettingsPages;
--
--  METHOD: wpAddSettingsPages                             ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpAddToObjUseList;
--
--  METHOD: wpAddToObjUseList                              ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpAllocMem;
--
--  METHOD: wpAllocMem                                     ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--     This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpClose;
--
--  METHOD: wpClose                                        ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpCopiedFromTemplate;
--
--  METHOD: wpCopiedFromTemplate                           ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpCopyObject;
--
--  METHOD: wpCopyObject                                   ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpCreateFromTemplate;
--
--  METHOD: wpCreateFromTemplate                           ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpCreateShadowObject;
--
--  METHOD: wpCreateShadowObject                           ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpDelete;
--
--  METHOD: wpDelete                                       ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpDeleteFromObjUseList;
--
--  METHOD: wpDeleteFromObjUseList                         ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpDoesObjectMatch;
--
--  METHOD: wpDoesObjectMatch                              ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpDraggedOverObject;
--
--  METHOD: wpDraggedOverObject                            ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpDragOver;
--
--  METHOD: wpDragOver                                     ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpDrop;
--
--  METHOD: wpDrop                                         ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpDroppedOnObject;
--
--  METHOD: wpDroppedOnObject                              ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpEndConversation;
--
--  METHOD: wpEndConversation                              ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpFilterPopupMenu;
--
--  METHOD: wpFilterPopupMenu                              ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpFindUseItem;
--
--  METHOD: wpFindUseItem                                  ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpFormatDragItem;
--
--  METHOD: wpFormatDragItem                               ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpFree;
--
--  METHOD: wpFree                                         ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to disconnect and close the named pipe
--    created to communicate with the 'Show Method Description'
--    (SHOWDESC.EXE) program.  This method also kills that program.
--

override wpFreeMem;
--
--  METHOD: wpFreeMem                                      ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpHide;
--
--  METHOD: wpHide                                         ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpInitData;
--
--  METHOD: wpInitData                                     ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpInsertPopupMenuItems;
--
--  METHOD: wpInsertPopupMenuItems                         ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpInsertSettingsPage;
--
--  METHOD: wpInsertSettingsPage                           ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpMenuItemSelected;
--
--  METHOD: wpMenuItemSelected                             ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--    In addition, this method processes the input from the
--    "Open tutorial" menu item added by this class.
--

override wpModifyPopupMenu;
--
-- METHOD: wpModifyPopupMenu                              ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--    In addition, this method adds the "Open tutorial" item to the
--    "Open" menu of the object's context menu,
--

override wpOpen;
--
--  METHOD: wpOpen                                         ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--    In addition, this method displays the current open view for the
--    object.  If no view is open, a new open view is created.
--

override wpQueryConfirmations;
--
--  METHOD: wpQueryConfirmations                           ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryDefaultView;
--
--  METHOD: wpQueryDefaultView                             ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryDetailsData;
--
--  METHOD: wpQueryDetailsData                             ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryHandle;
--
--  METHOD: wpQueryHandle                                  ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryIcon;
--
--  METHOD: wpQueryIcon                                    ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryIconData;
--
--  METHOD: wpQueryIconData                                ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryRealName;
--
--  METHOD: wpQueryRealName                                ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryStyle;
--
--  METHOD: wpQueryStyle                                   ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryTitle;
--
--  METHOD: wpQueryTitle                                   ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpQueryType;
--
--  METHOD: wpQueryType                                    ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpRegisterView;
--
--  METHOD: wpRegisterView                                 ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpRender;
--
--  METHOD: wpRender                                       ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpRenderComplete;
--
--  METHOD: wpRenderComplete                               ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpRestore;
--
--  METHOD: wpRestore                                      ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpRestoreData;
--
--  METHOD: wpRestoreData                                  ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpRestoreLong;
--
--  METHOD: wpRestoreLong                                  ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpRestoreState;
--
-- METHOD: wpRestoreState                                 ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--    In addition, this method queries the title to "force" all views of
--    the object's title to be backwards upon IPL.
--

override wpRestoreString;
--
--  METHOD: wpRestoreString                                ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSaveData;
--
--  METHOD: wpSaveData                                     ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSaveDeferred;
--
--  METHOD: wpSaveDeferred                                 ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSaveImmediate;
--
--  METHOD: wpSaveImmediate                                ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSaveLong;
--
--  METHOD: wpSaveLong                                     ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSaveState;
--
--  METHOD: wpSaveState                                    ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSaveString;
--
--  METHOD: wpSaveString                                   ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSetDefaultView;
--
--  METHOD: wpSetDefaultView                               ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSetIcon;
--
--  METHOD: wpSetIcon                                      ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSetIconData;
--
--  METHOD: wpSetIconData                                  ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSetRealName;
--
--  METHOD: wpSetRealName                                  ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSetStyle;
--
--  METHOD: wpSetStyle                                     ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--


override wpSetTitle;
--
--  METHOD: wpSetTitle                                     ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--    In addition, this method reverses the title supplied by
--    the user.
--

override wpSetType;
--
--  METHOD: wpSetType                                      ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--


override wpSetup;
--
-- METHOD: wpSetup                                        ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpSwitchTo;
--
--  METHOD: wpSwitchTo                                     ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpUnlockObject;
--
--  METHOD: wpUnlockObject                                 ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpUnInitData;
--
--  METHOD: wpUnInitData                                   ( ) PRIVATE
--                                                         (X) PUBLIC
--  DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--


#******************************************************************************
#   Define new class methods
#******************************************************************************
HMODULE clsQueryModuleHandle(), class;
--
-- METHOD: clsQueryModuleHandle
--
-- DESCRIPTION:
--
--   This method obtains and returns the module handle for the object class.
--
-- RETURN:
--
--   0        - Unsuccessful execution
--   Non-zero - Module handle
--

#******************************************************************************
#   Specify class methods being overridden
#******************************************************************************

override wpclsCreateDefaultTemplates, class;
--
-- METHOD: wpclsCreateDefaultTemplates
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsFindObjectEnd, class;
--
-- METHOD: wpclsFindObjectEnd
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsFindObjectFirst, class;
--
-- METHOD: wpclsFindObjectFirst
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsFindObjectNext, class;
--
-- METHOD: wpclsFindObjectNext
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsInitData, class;
--
-- METHOD: wpclsInitData
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--    In addition, this method initializes the DLL module handle.
--

override wpclsMakeAwake, class;
--
-- METHOD: wpclsMakeAwake
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsNew, class;
--
-- METHOD: wpclsNew
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryDefaultView, class;
--
-- METHOD: wpclsQueryDefaultView
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--    In addition, this method is overridden to make the default open
--    view of the instances of this class to the "Open tutorial" view.
--

override wpclsQueryDetails, class;
--
-- METHOD: wpclsQueryDetails
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryDetailsInfo, class;
--
-- METHOD: wpclsQueryDetailsInfo
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryFolder, class;
--
-- METHOD: wpclsQueryFolder
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryIcon, class;
--
-- METHOD: wpclsQueryIcon
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryIconData, class;
--
-- METHOD: wpclsQueryIconData                             ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--    In addition, the method is overridden to define the icon
--    for the class.
--

override wpclsQueryInstanceFilter, class;
--
-- METHOD: wpclsQueryInstanceFilter
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryInstanceType, class;
--
-- METHOD: wpclsQueryInstanceType
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryObject, class;
--
-- METHOD: wpclsQueryObject
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQuerySettingsPageSize, class;
--
-- METHOD: wpclsQuerySettingsPageSize
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryStyle, class;
--
-- METHOD: wpclsQueryStyle
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsQueryTitle, class;
--
-- METHOD: wpclsQueryTitle
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

override wpclsUnInitData, class;
--
-- METHOD: wpclsUnInitData
--
-- DESCRIPTION:
--
--    This method is overridden to invoke 'DisplayMethodInfo'.
--

